@@ -300,47 +300,47 @@ adjustTol <- function(val, tol = 0.00001) { #SYBIL_SETTINGS("TOLERANCE")
             "glpkAPI" = {
 				print(sprintf("%s : creating MILP using GLPK solver....",format(Sys.time(), "%d-%m-%Y %X")))
                 out <- vector(mode = "list", length = 4)
-                prob <- initProbGLPK();# new problem
+                prob <- glpkAPI::initProbGLPK();# new problem
                
-                out[[1]] <-  addRowsGLPK(prob, nrows=nr+nIrrev+2*nRev +1)
-				outj <- addColsGLPK(prob, ncols=nc+nIrrev+nRev+nRev_on )
+                out[[1]] <-  glpkAPI::addRowsGLPK(prob, nrows=nr+nIrrev+2*nRev +1)
+				outj <- glpkAPI::addColsGLPK(prob, ncols=nc+nIrrev+nRev+nRev_on )
 				#setColNameGLPK(prob,c(1:(nc+nIrrev+2*nRev )),cNames );
-				mapply(setColNameGLPK, j = c(1:(nc+nIrrev+nRev+nRev_on )), cname = cNames, MoreArgs = list(lp = prob));
-				setObjDirGLPK(prob, GLP_MIN);
+				mapply(glpkAPI::setColNameGLPK, j = c(1:(nc+nIrrev+nRev+nRev_on )), cname = cNames, MoreArgs = list(lp = prob));
+				glpkAPI::setObjDirGLPK(prob, glpkAPI::GLP_MIN);
                 ## note: when FX or LO value taken from lb and when UP take from UP
-               rtype <- c(rep(GLP_FX, nr),GLP_LO, rep(GLP_UP, nIrrev+2*nRev  ))# objective >=
+               rtype <- c(rep(glpkAPI::GLP_FX, nr),glpkAPI::GLP_LO, rep(glpkAPI::GLP_UP, nIrrev+2*nRev  ))# objective >=
 	       
 	        # set the right hand side Sv = b
 
-				out[[4]] <- setRowsBndsGLPK(prob, c(1:(nr+nIrrev+2*nRev +1)), lb=rlower, ub=rupper,type=rtype )
+				out[[4]] <- glpkAPI::setRowsBndsGLPK(prob, c(1:(nr+nIrrev+2*nRev +1)), lb=rlower, ub=rupper,type=rtype )
         
 	        # add upper and lower bounds: ai <= vi <= bi
-                cc <- setColsBndsObjCoefsGLPK(prob, c(1:(nc+nIrrev+nRev+nRev_on )),   lower,   upper,  cobj   )
+                cc <- glpkAPI::setColsBndsObjCoefsGLPK(prob, c(1:(nc+nIrrev+nRev+nRev_on )),   lower,   upper,  cobj   )
                 if (verboseMode > 2) { print(cc);	}		
 				#nzLHS=nzijr(LHS);
         	#print(nzLHS);
 				TMPmat <- as(LHS, "TsparseMatrix")
                 #cc <- loadMatrixGLPK(prob,   nzLHS$ne,   nzLHS$ia,  nzLHS$ja,  nzLHS$ar     )
-				cc <- loadMatrixGLPK(prob,length(TMPmat@x),ia  = TMPmat@i + 1,ja  = TMPmat@j + 1,ra  = TMPmat@x)
+				cc <- glpkAPI::loadMatrixGLPK(prob,length(TMPmat@x),ia  = TMPmat@i + 1,ja  = TMPmat@j + 1,ra  = TMPmat@x)
                 if (verboseMode > 3) {  print(c("Load matrix GLPK return code:",cc));}# technical msgs
-                ctype <- c(rep(GLP_CV, nc), rep(GLP_BV,nIrrev+nRev+nRev_on ));
-				setColsKindGLPK(prob,c(1:(nc+nIrrev+nRev+nRev_on )),ctype);
+                ctype <- c(rep(glpkAPI::GLP_CV, nc), rep(glpkAPI::GLP_BV,nIrrev+nRev+nRev_on ));
+				glpkAPI::setColsKindGLPK(prob,c(1:(nc+nIrrev+nRev+nRev_on )),ctype);
 
                if (verboseMode > 2) {                      
 					fname=format(Sys.time(), "glpk_eFBA_%Y%m%d_%H%M.lp");
 					print(sprintf("Writing problem to file: %s/%s ...",getwd(),fname));
-                	writeLPGLPK(prob,fname);
+                	glpkAPI::writeLPGLPK(prob,fname);
                 	print(format(Sys.time(), "Testing time : %Y%m%d %X Solving..."));
                 }
 				
 				## Solve
-            setMIPParmGLPK(PRESOLVE,GLP_ON);
-			lp_ok=solveMIPGLPK(prob);
-			return_codeGLPK(lp_ok);
-			lp_stat=mipStatusGLPK(prob);
-			status_codeGLPK(lp_stat);
-			lp_obj=mipObjValGLPK(prob);
-			colst=mipColsValGLPK(prob);
+            glpkAPI::setMIPParmGLPK(glpkAPI::PRESOLVE,glpkAPI::GLP_ON);
+			lp_ok=glpkAPI::solveMIPGLPK(prob);
+			glpkAPI::return_codeGLPK(lp_ok);
+			lp_stat=glpkAPI::mipStatusGLPK(prob);
+			glpkAPI::status_codeGLPK(lp_stat);
+			lp_obj=glpkAPI::mipObjValGLPK(prob);
+			colst=glpkAPI::mipColsValGLPK(prob);
 			newFlux=colst
 	       ## --- 
 	        #newFlux=adjustTol(newFlux,tol=Tf);
@@ -351,24 +351,24 @@ adjustTol <- function(val, tol = 0.00001) { #SYBIL_SETTINGS("TOLERANCE")
            "cplexAPI" = {
                 print(sprintf("%s : creating MILP using CPLEX solver....",format(Sys.time(), "%d-%m-%Y %X")))
 				out <- vector(mode = "list", length = 3)
-				prob <- openProbCPLEX()
-				out <- setIntParmCPLEX(prob$env, CPX_PARAM_SCRIND, CPX_OFF)
+				prob <- cplexAPI::openProbCPLEX()
+				out <- cplexAPI::setIntParmCPLEX(prob$env, cplexAPI::CPX_PARAM_SCRIND, cplexAPI::CPX_OFF)
 		                
-                chgProbNameCPLEX(prob$env, prob$lp, "eFBA rxn cplex");
+                cplexAPI::chgProbNameCPLEX(prob$env, prob$lp, "eFBA rxn cplex");
                 #E,L,"G"
                 rtype <- c(rep("E",nr),"G", rep("L", nIrrev+2*nRev  ))
-                setObjDirCPLEX(prob$env, prob$lp, CPX_MIN);
+                cplexAPI::setObjDirCPLEX(prob$env, prob$lp, cplexAPI::CPX_MIN);
 
-                out[[1]] <- newRowsCPLEX(prob$env, prob$lp,
+                out[[1]] <- cplexAPI::newRowsCPLEX(prob$env, prob$lp,
                                          nrows=nr+nIrrev+2*nRev +1, rhs=rupper, sense=rtype)
 
-                out[[2]] <- newColsCPLEX(prob$env, prob$lp,
+                out[[2]] <- cplexAPI::newColsCPLEX(prob$env, prob$lp,
                                          nc+nIrrev+nRev+nRev_on , obj=cobj, lb=lower, ub=upper,cnames=cNames)
 				
 				print(sprintf("%s : step 2: nzijr....",format(Sys.time(), "%d-%m-%Y %X")))
                         # constraint matrix
 				TMPmat <- as(LHS, "TsparseMatrix")
-				out[[3]] <- chgCoefListCPLEX(prob$env, prob$lp,#lp@oobj@env, lp@oobj@lp,
+				out[[3]] <- cplexAPI::chgCoefListCPLEX(prob$env, prob$lp,#lp@oobj@env, lp@oobj@lp,
                                    nnz = length(TMPmat@x),
                                    ia  = TMPmat@i,
                                    ja  = TMPmat@j,
@@ -378,13 +378,13 @@ adjustTol <- function(val, tol = 0.00001) { #SYBIL_SETTINGS("TOLERANCE")
 #print(sprintf("%s : step 3: chngCoef....",format(Sys.time(), "%d-%m-%Y %X")))				
 
 				ctype<-c(rep('C', nc), rep('B',nIrrev+nRev+nRev_on ));
-				status = copyColTypeCPLEX (prob$env, prob$lp, ctype);
-				check <- setObjDirCPLEX(prob$env, prob$lp, CPX_MIN);
+				status = cplexAPI::copyColTypeCPLEX (prob$env, prob$lp, ctype);
+				check <- cplexAPI::setObjDirCPLEX(prob$env, prob$lp, cplexAPI::CPX_MIN);
 		
                 if (verboseMode > 2) {                      
                       fname=format(Sys.time(), "Cplex_eFBA_%Y%m%d_%H%M.lp");
 					  print(sprintf("Writing problem to file: %s/%s  ...",getwd(),fname));
-					  writeProbCPLEX(prob$env, prob$lp, fname);
+					  cplexAPI::writeProbCPLEX(prob$env, prob$lp, fname);
 		       }
 			   
 			   #set precision 
@@ -397,14 +397,14 @@ adjustTol <- function(val, tol = 0.00001) { #SYBIL_SETTINGS("TOLERANCE")
 				print(unlist(out))
 			print(sprintf("%s : Solving MILP using CPLEX solver....",format(Sys.time(), "%d-%m-%Y %X")))
 #		       print("Solving...");		 
-			   lp_ok     <- mipoptCPLEX(prob$env, prob$lp);
+			   lp_ok     <- cplexAPI::mipoptCPLEX(prob$env, prob$lp);
 	           print(lp_ok);
-				sol=solutionCPLEX(prob$env, prob$lp);
+				sol=cplexAPI::solutionCPLEX(prob$env, prob$lp);
 	       
 				if (verboseMode > 3) {print(sol);}	
                
                lp_obj=sol$objval;
-               lp_stat   <- getStatCPLEX(prob$env, prob$lp)
+               lp_stat   <- cplexAPI::getStatCPLEX(prob$env, prob$lp)
               
                 colst=sol$x;
                 
